.. _virtualnetwork module:

:mod:`oca.virtualnetwork`
--------------------------------

.. autoclass:: oca.VirtualNetwork
    :members:

.. autoclass:: oca.VirtualNetworkPool
    :members: info
    :no-inherited-members:
